@@ -18,6 +18,7 @@
 import json
 import logging
 import time
+import base64
 from builtins import object
 from json import JSONDecodeError
 from urllib.parse import quote_plus
@@ -120,7 +121,7 @@ class ParaClient:
         """
         if token:
             parts = token.split(".")
-            decoded = json.loads(parts[1])
+            decoded = json.loads(base64.b64decode(parts[1] + "==").decode("utf-8"))
             if decoded and "exp" in decoded:
                 self.__tokenKeyExpires = decoded["exp"]
                 self.__tokenKeyNextRefresh = decoded["refresh"]
